import { DefaultParams } from '@modules/ad/core/application/ports/default-params.type';
import { DefaultParamsProvider } from '@modules/ad/infrastructure/default-params-provider';
import { ConfigService } from '@nestjs/config';
import { Test, TestingModule } from '@nestjs/testing';

const mockConfigService = {
  get: jest.fn().mockImplementation((value: string) => {
    switch (value) {
      case 'DEPARTURE_MARGIN':
        return 900;
      case 'ROLE':
        return 'passenger';
      case 'SEATS_PROPOSED':
        return 3;
      case 'SEATS_REQUESTED':
        return 1;
      case 'STRICT_FREQUENCY':
        return 'false';
      case 'DEFAULT_TIMEZONE':
        return 'Europe/Paris';
      default:
        return 'some_default_value';
    }
  }),
};

describe('DefaultParamsProvider', () => {
  let defaultParamsProvider: DefaultParamsProvider;

  beforeAll(async () => {
    const module: TestingModule = await Test.createTestingModule({
      imports: [],
      providers: [
        DefaultParamsProvider,
        {
          provide: ConfigService,
          useValue: mockConfigService,
        },
      ],
    }).compile();

    defaultParamsProvider = module.get<DefaultParamsProvider>(
      DefaultParamsProvider,
    );
  });

  it('should be defined', () => {
    expect(defaultParamsProvider).toBeDefined();
  });

  it('should provide default params', async () => {
    const params: DefaultParams = defaultParamsProvider.getParams();
    expect(params.SUN_MARGIN).toBe(900);
    expect(params.PASSENGER).toBeTruthy();
    expect(params.DRIVER).toBeFalsy();
    expect(params.DEFAULT_TIMEZONE).toBe('Europe/Paris');
  });
});
